@@ -1,7 +1,7 @@
 /*
  * This file is part of the recoverjpeg program.
  *
- * Copyright (c) 2004-2010 Samuel Tardieu <sam@rfc1149.net>
+ * Copyright (c) 2004-2012 Samuel Tardieu <sam@rfc1149.net>
  * http://www.rfc1149.net/devel/recoverjpeg
  *
  * recoverjpeg is released under the GNU General Public License
@@ -15,13 +15,17 @@
 #include <sys/types.h>
 
 #ifdef __cplusplus
-extern "C" {
-#endif // __cplusplus
+extern "C"
+{
+#endif				// __cplusplus
 
-size_t atol_suffix(char *arg);
+  size_t atol_suffix(char *arg);
+
+  void display_version_and_exit(const char *program_name)
+    __attribute__ ((noreturn));
 
 #ifdef __cplusplus
 }
-#endif // __cplusplus
+#endif				// __cplusplus
 
-#endif // _UTILS_H
+#endif				// _UTILS_H
